# inspiration from https://chocolatey.org/packages/jdk8
program_files = node['java_se']['arch'] == 'x64' ? ENV['ProgramW6432'] : ENV['ProgramFiles(x86)']

java_home = node['java_se']['java_home']
if java_home.nil? || java_home.empty?
  java_home = "#{program_files}\\Java\\jdk#{node['java_se']['version']}"
else
  install_dir = "INSTALLDIR=\"#{java_home}\""
end

win_jre_home = node['java_se']['win_jre_home']
if win_jre_home.nil? || win_jre_home.empty?
  win_jre_home = "#{program_files}\\Java\\jre#{node['java_se']['version']}"
else
  jre_install_dir = "/INSTALLDIRPUBJRE=\"#{win_jre_home}\""
end

file_cache_path = node['java_se']['file_cache_path']

execute "install #{::File.basename(file_cache_path)} to #{java_home} with JRE #{win_jre_home}" do
  command "\"#{file_cache_path}\" /s ADDLOCAL=\"#{node['java_se']['win_addlocal']}\" #{install_dir} #{jre_install_dir}"
  not_if { ::File.exist?(java_home) }
end

win_javalink = node['java_se']['win_javalink']
javalink_dir = win_javalink[0..win_javalink.rindex('\\') - 1]

# create each directory in win_javalink path except bin (the last path element)
directory javalink_dir do
  recursive true
  not_if { ::File.exist?(path) }
end

link win_javalink do
  to "#{java_home}\\bin"
end

env 'JAVA_HOME' do
  value java_home
end

env 'JRE_HOME' do
  value win_jre_home
end

env 'Add java_se JDK to path' do
  key_name 'PATH'
  action :modify
  delim ::File::PATH_SEPARATOR
  value "#{java_home}\\bin"
end

# JRE is supposed to come before the JDK on the stock path install. Since chef prepends, JRE env resource comes second.
env 'Add java_se JRE to path' do
  key_name 'PATH'
  action :modify
  delim ::File::PATH_SEPARATOR
  value "#{win_jre_home}\\bin"
end
